@@ -38,19 +38,31 @@ URI_FORMAT = """\
 
 
 def parse_url(url):
-    auth = userid = password = None
+    port = path = auth = userid = password = None
     scheme = urlparse(url).scheme
     parts = urlparse(url.replace("%s://" % (scheme, ), "http://"))
-    netloc = parts.netloc
-    if '@' in netloc:
-        auth, _, netloc = partition(parts.netloc, '@')
-        userid, _, password = partition(auth, ':')
-    hostname, _, port = partition(netloc, ':')
-    path = parts.path or ""
-    if path and path[0] == '/':
-        path = path[path.index('/') + 1:]
+
+    # The first pymongo.Connection() argument (host) can be
+    # a mongodb connection URI. If this is the case, don't
+    # use port but let pymongo get the port(s) from the URI instead.
+    # This enables the use of replica sets and sharding.
+    # See pymongo.Connection() for more info.
+    if scheme != 'mongodb':
+        netloc = parts.netloc
+        if '@' in netloc:
+            auth, _, netloc = partition(parts.netloc, '@')
+            userid, _, password = partition(auth, ':')
+        hostname, _, port = partition(netloc, ':')
+        path = parts.path or ""
+        if path and path[0] == '/':
+            path = path[1:]
+        port = port and int(port) or port
+    else:
+        # strip the scheme since it is appended automatically
+        hostname = url[len('mongodb://'):]
+
     return dict({"hostname": hostname,
-                 "port": port and int(port) or None,
+                 "port": port or None,
                  "userid": userid or None,
                  "password": password or None,
                  "transport": scheme,
@@ -63,16 +75,16 @@ class BrokerConnection(object):
 
     :param URL:  Connection URL.
 
-    :keyword hostname: Default Hostname/address if not provided in the URL.
-    :keyword userid: Default username if not provided in the URL.
+    :keyword hostname: Default host name/address if not provided in the URL.
+    :keyword userid: Default user name if not provided in the URL.
     :keyword password: Default password if not provided in the URL.
     :keyword virtual_host: Default virtual host if not provided in the URL.
     :keyword port: Default port if not provided in the URL.
-    :keyword ssl: Use ssl to connect to the server. Default is ``False``.
+    :keyword ssl: Use SSL to connect to the server. Default is ``False``.
       May not be supported by the specified transport.
     :keyword transport: Default transport if not specified in the URL.
     :keyword connect_timeout: Timeout in seconds for connecting to the
-      server. May not be suported by the specified transport.
+      server. May not be supported by the specified transport.
     :keyword transport_options: A dict of additional connection arguments to
       pass to alternate kombu channel implementations.  Consult the transport
       documentation for available options.
@@ -167,7 +179,7 @@ class BrokerConnection(object):
         """Wait for a single event from the server.
 
         :keyword timeout: Timeout in seconds before we give up.
-            Raises :exc:`socket.timeout` if the timeout is execeded.
+            Raises :exc:`socket.timeout` if the timeout is exceeded.
 
         Usually used from an event loop.
 
@@ -234,7 +246,7 @@ class BrokerConnection(object):
     def ensure(self, obj, fun, errback=None, max_retries=None,
             interval_start=1, interval_step=1, interval_max=1, on_revive=None):
         """Ensure operation completes, regardless of any channel/connection
-        errors occuring.
+        errors occurring.
 
         Will retry by establishing the connection, and reapplying
         the function.
@@ -267,10 +279,8 @@ class BrokerConnection(object):
 
         """
 
-        max_retries = max_retries or 0
-
         @wraps(fun)
-        def _insured(*args, **kwargs):
+        def _ensured(*args, **kwargs):
             got_connection = 0
             for retries in count(0):
                 try:
@@ -278,14 +288,16 @@ class BrokerConnection(object):
                 except self.connection_errors + self.channel_errors, exc:
                     self._debug("ensure got exception: %r" % (exc, ),
                                 exc_info=sys.exc_info())
-                    if got_connection or \
-                            max_retries and retries > max_retries:
+                    if got_connection:
+                        raise
+                    if max_retries is not None and retries > max_retries:
                         raise
                     errback and errback(exc, 0)
                     self._connection = None
                     self.close()
-                    remaining_retries = max_retries and \
-                                            max(max_retries - retries, 1)
+                    remaining_retries = None
+                    if max_retries is not None:
+                        remaining_retries = max(max_retries - retries, 1)
                     self.ensure_connection(errback,
                                            remaining_retries,
                                            interval_start,
@@ -298,8 +310,8 @@ class BrokerConnection(object):
                         on_revive(new_channel)
                     got_connection += 1
 
-        _insured.func_name = _insured.__name__ = "%s(insured)" % fun.__name__
-        return _insured
+        _ensured.func_name = _ensured.__name__ = "%s(ensured)" % fun.__name__
+        return _ensured
 
     def autoretry(self, fun, channel=None, **ensure_options):
         """Decorator for functions supporting a ``channel`` keyword argument.
@@ -378,7 +390,7 @@ class BrokerConnection(object):
                 info[key] = value
         return info
 
-    def __hash__(self):
+    def __eqhash__(self):
         return hash("|".join(map(str, self.info().itervalues())))
 
     def as_uri(self, include_password=False):
@@ -386,15 +398,21 @@ class BrokerConnection(object):
         port = fields["port"]
         userid = fields["userid"]
         password = fields["password"]
-        url = "%s://" % fields["transport"]
+        transport = fields["transport"]
+        url = "%s://" % transport
         if userid:
             url += userid
             if include_password and password:
                 url += ':' + password
             url += '@'
         url += fields["hostname"]
-        if port:
+
+        # If the transport equals 'mongodb' the
+        # hostname contains a full mongodb connection
+        # URI. Let pymongo retreive the port from there.
+        if port and transport != "mongodb":
             url += ':' + str(port)
+
         url += '/' + fields["virtual_host"]
         return url
 
@@ -569,7 +587,7 @@ class BrokerConnection(object):
 
     @property
     def host(self):
-        """The host as a hostname/port pair separated by colon."""
+        """The host as a host name/port pair separated by colon."""
         return ":".join([self.hostname, str(self.port)])
 
     @property
@@ -626,22 +644,22 @@ class Resource(object):
         if self.limit:
             while 1:
                 try:
-                    resource = self._resource.get(block=block, timeout=timeout)
+                    R = self._resource.get(block=block, timeout=timeout)
                 except Empty:
                     self._add_when_empty()
                 else:
-                    resource = self.prepare(resource)
-                    self._dirty.add(resource)
+                    R = self.prepare(R)
+                    self._dirty.add(R)
                     break
         else:
-            resource = self.prepare(self.new())
+            R = self.prepare(self.new())
 
         @wraps(self.release)
         def _release():
-            self.release(resource)
-        resource.release = _release
+            self.release(R)
+        R.release = _release
 
-        return resource
+        return R
 
     def prepare(self, resource):
         return resource
@@ -657,9 +675,7 @@ class Resource(object):
         of defective resources."""
         if self.limit:
             self._dirty.discard(resource)
-            self.close_resource(resource)
-        else:
-            self.close_resource(resource)
+        self.close_resource(resource)
 
     def release(self, resource):
         """Release resource so it can be used by another thread.
@@ -690,7 +706,10 @@ class Resource(object):
                 dres = dirty.pop()
             except KeyError:
                 break
-            self.close_resource(dres)
+            try:
+                self.close_resource(dres)
+            except AttributeError:  # Issue #78
+                pass
 
         mutex = getattr(resource, "mutex", None)
         if mutex:
@@ -701,24 +720,30 @@ class Resource(object):
                     res = resource.queue.pop()
                 except IndexError:
                     break
-                self.close_resource(res)
+                try:
+                    self.close_resource(res)
+                except AttributeError:
+                    pass  # Issue #78
         finally:
             if mutex:
                 mutex.release()
 
     if os.environ.get("KOMBU_DEBUG_POOL"):
-
         _orig_acquire = acquire
         _orig_release = release
 
         _next_resource_id = 0
 
         def acquire(self, *args, **kwargs):  # noqa
+            import traceback
             id = self._next_resource_id = self._next_resource_id + 1
             print("+%s ACQUIRE %s" % (id, self.__class__.__name__, ))
             r = self._orig_acquire(*args, **kwargs)
             r._resource_id = id
             print("-%s ACQUIRE %s" % (id, self.__class__.__name__, ))
+            if not hasattr(r, "acquired_by"):
+                r.acquired_by = []
+            r.acquired_by.append(traceback.format_stack())
             return r
 
         def release(self, resource):  # noqa
