@@ -24,6 +24,14 @@ if sys.version_info >= (3, 0):
             return s.decode()
         return s
 
+    def ensure_bytes(s):
+        if not isinstance(s, bytes):
+            return bytes_to_str(s)
+        return s
+
+    str_t = str
+    bytes_t = bytes
+
 else:
 
     def str_to_bytes(s):  # noqa
@@ -34,6 +42,10 @@ else:
     def bytes_to_str(s):  # noqa
         return s
 
+    str_t = unicode
+    bytes_t = str
+    ensure_bytes = str_to_bytes
+
 
 if sys.platform.startswith("java"):
 
